@@ -1,4 +1,4 @@
-#![warn(rust_2018_idioms)]
+#![warn(warnings)]
 #![allow(clippy::result_unit_err)]
 
 #[macro_use]
